***********************
* File starts by appending different years of data to each of the beer and soda categories
***********************		


***********************
* For both beer and soda, loop over categories and years and append the data files to cover all categories and years
***********************		

	local catnums = "5000 5010"
	local iter = 1
	forvalues year = 2006(1)2011 {
	foreach cat of local catnums {
		use "C:\Google Drive\SuperBowlShare\StataData\data_`cat'_`year' .dta"
		gen categorynum=`cat'
	
	
		if `iter'>1 {
			append using "C:\Google Drive\SuperBowlShare\StataData\beer_data"
		}
		save "C:\Google Drive\SuperBowlShare\StataData\beer_data", replace
		local iter = `iter' + 1
	}
	}
	
	
	clear
	
	local catnums = "1484 1553"
	local iter = 1
	forvalues year = 2006(1)2011 {
	foreach cat of local catnums {
		use "C:\Google Drive\SuperBowlShare\StataData\data_`cat'_`year' .dta"
		gen categorynum=`cat'
	
	
		if `iter'>1 {
			append using "C:\Google Drive\SuperBowlShare\StataData\soda_data"
		}
		save "C:\Google Drive\SuperBowlShare\StataData\soda_data", replace
		local iter = `iter' + 1
	}
	}
	
***********************
* Append the beer and soda data together for formatting ...  will be split again later
***********************		
	use "C:\Google Drive\SuperBowlShare\StataData\beer_data"
	gen cat=2
	append using "C:\Google Drive\SuperBowlShare\StataData\soda_data"
	replace cat=1 if cat==.
	
	***********************
	*Define the week relative to the Super Bowl for estimating effects on SB purchases and ad effects on post-Super Bowl purchases
	***********************		
		gen superweek=10000
		replace superweek=endweekdate+1-mdy(2,5,2012)
		replace superweek=endweekdate+1-mdy(2,6,2011) if year(endweekdate)==2011
		replace superweek=endweekdate+1-mdy(2,7,2010) if year(endweekdate)==2010
		replace superweek=endweekdate+1-mdy(2,1,2009) if year(endweekdate)==2009
		replace superweek=endweekdate+1-mdy(2,3,2008) if year(endweekdate)==2008
		replace superweek=endweekdate+1-mdy(2,4,2007) if year(endweekdate)==2007
		replace superweek=endweekdate+1-mdy(2,5,2006) if year(endweekdate)==2006
		
		replace superweek=floor(superweek/7)
		
		gen wks26=1
		
		replace wks26=0 if superweek>25
		keep if wks26

	gen year=year(endweekdate)
	gen barrels =  (volume/128)/55
	egen annual_barrels = sum(barrels),by(brand_desc year)
	
	***********************
	*Will aggregate again and want feature and display to be volume weighted.  Price will be calculated later based on Rev and Vol
	***********************		
		gen vfeature=feature*volume
		gen vdisplay=display*volume
		collapse (sum) revenue volume vfeature vdisplay  ,by(DMA year superweek cat categorynum brand_desc)
		gen feature=vfeature/volume
		gen display=vdisplay/volume
		drop vfeature vdisplay
	
	save "C:\Google Drive\SuperbowlShare\StataData\AllBrandsDMAsW", replace

clear
use "C:\Google Drive\SuperbowlShare\StataData\AllBrandsDMAsW"


	***********************
	*Identify DMAs with restrictions on selling alcohol
	***********************		
		gen restricted=0
		replace restricted=1 if DMA==504 
		replace restricted=1 if DMA==650 
		replace restricted=1 if DMA==512 
		replace restricted=1 if DMA==508 
		replace restricted=1 if DMA==521 
		replace restricted=1 if DMA==613 



***********************************************
* Brand Assignment Names for Ratings ... need same identifier for sales and ad data
***********************************************
	gen brand=""
	
	replace brand="BUD LIGHT BEER"                        if brand_desc=="BUD LIGHT"                 
	replace brand="BUDWEISER BEER"                        if brand_desc=="BUDWEISER"
	replace brand="BUDWEISER SELECT 55 BEER"              if brand_desc=="BUDWEISER SELECT LIGHT"
	replace brand="BUDWEISER SELECT BEER"                 if brand_desc=="BUDWEISER SELECT"
	replace brand="COCA-COLA CLASSIC REG SOFT DRINK"      if brand_desc=="COCA-COLA R"
	replace brand="COCA-COLA ZERO DIET SOFT DRINK"        if brand_desc=="COCA-COLA ZERO DT"
	replace brand="DR PEPPER CHERRY REG SOFT DRINK"       if brand_desc=="DR PEPPER CHERRY R"
	replace brand="MICHELOB ULTRA BEER"                   if brand_desc=="MICHELOB ULTRA LIGHT"
	replace brand="PEPSI DIET SOFT DRINK"                 if brand_desc=="PEPSI DT"
	replace brand="PEPSI MAX DIET SOFT DRINK"             if brand_desc=="PEPSI MAX DT"
	replace brand="PEPSI REG SOFT DRINK"                  if brand_desc=="PEPSI R"
	replace brand="SIERRA MIST FREE DIET SOFT DRINK"      if brand_desc=="SIERRA MIST FREE DT"
	replace brand="SIERRA MIST REG SOFT DRINK"            if brand_desc=="SIERRA MIST R"
	replace brand="STELLA ARTOIS BEER"                    if brand_desc=="STELLA ARTOIS"
	gen newp=0
	replace newp=1 

	***********************
	*Merge in the Ratings data from the Ad Views source.
	*  Includes ratings separately for different brands.  We eventually pool across those
	*  to calculate a ratings measure for the game.
	*  Eventually we'll only keep this for markets 57-210 and use the SB ratings data file for the top 56
	***********************		
		sort brand year DMA
		merge m:1 brand year DMA using "C:\Dropbox\SuperbowlAds\Data\Ratings\RatingsByBrand"
		
		***********************
		*Only keep SB ratings data that cover the brands and years we analyze
		***********************		
		drop if _merge==2
		egen sumgrps=sum(grptv),by(year brand_desc)
		tab DMA year if _merge==1 & sumgrps>0 & sumgrps<.
		
	egen totrev=sum(revenue),by(DMA year categorynum)
	egen totvol=sum(volume),by(DMA year categorynum)


save "C:\Google Drive\SuperBowlShare\StataData\AllDataW", replace


***********************************************
* TopBrandManyDMAs.do starts with the above file.  But a couple others need to be run
* first to create other relevant data merged in within TopBrandManyDMAs.do
***********************************************



