
set more off

use "C:\Google Drive\SuperbowlShare\StataData\AllDataW"
	*This comes from MergeCatYearWeek.do

local maxbrand = 4

rename DMA dma

rename grptvhouse SBgrps
rename imp000 SBimps
rename units SBunits
rename _merge SBmerge

**********************************
* Load in and Merge Brand Lists and Aggregation Identifier to focal brands, e.g. Coke, Pepsi, Bud etc.
***********************************
	preserve
		clear
		insheet using "C:\Google Drive\SuperbowlShare\RawData\KiltsBrandsSoftDrinks.txt", names
		gen cat=1
		save "C:\Google Drive\SuperbowlShare\StataData\KiltsBrands", replace
		clear
		insheet using "C:\Google Drive\SuperbowlShare\RawData\KiltsBrands.txt", names
		gen cat=2
		append using "C:\Google Drive\SuperbowlShare\StataData\KiltsBrands"
		sort brand_desc topbrand subbrand
		save "C:\Google Drive\SuperbowlShare\StataData\KiltsBrands", replace
	restore
	
	
	sort brand_desc
	
	merge m:1 brand_desc using "C:\Google Drive\SuperbowlShare\StataData\KiltsBrands"
	replace topbrand="BUDWEISER" if topbrand=="BUSCH"
	replace topbrand="OTHER" if topbrand==""
	replace topbrand="OTHER" if topbrand=="ASPEN EDGE"
	drop _merge
	drop if topbrand==""

**********************************
* Collapse data to Cat, TopBrand, market and year
***********************************
	
	gen vfeature = volume*feature
	gen vdisplay = volume*display
	collapse (sum) revenue volume vfeature vdisplay SBgrps SBimps SBunits , by(cat topbrand restricted dma year superweek) 
	gen feature=vfeature/volume
	gen display=vdisplay/volume
	drop vfeature vdisplay
	
	
	egen brandvol = sum(volume),by(cat topbrand)
	replace brandvol=0 if topbrand=="OTHER"
	gsort cat year superweek dma - brandvol
	by cat year superweek dma: gen brandrank1=_n
	egen brandrank=mode(brandrank1),by(cat topbrand)
	replace topbrand="OTHER" if brandrank>`maxbrand'
	
	gen vfeature = volume*feature
	gen vdisplay = volume*display
	collapse (sum) revenue volume vfeature vdisplay SBgrps SBimps SBunits , by(cat topbrand restricted dma year superweek) 
	gen feature=vfeature/volume
	gen display=vdisplay/volume
	drop vfeature vdisplay
	replace topbrand="OTHERBEER" if topbrand=="OTHER" & cat==2
	sort topbrand dma year


**********************************
* Load and Merge Pre-SB NFL GRPs
*   Created in PreSBnlfRatingsByBrand.do
***********************************
	preserve
		clear
		use "C:\Google Drive\SuperbowlShare\StataData\PreSBnflGRPs"
		keep if year>2005
		gen cat = 2
		replace cat = 1 if topbrand=="CANADA DRY"
		replace cat = 1 if topbrand=="COCA-COLA"
		replace cat = 1 if topbrand=="DR PEPPER"
		replace cat = 1 if topbrand=="JONES"
		replace cat = 1 if topbrand=="MTN DEW"
		replace cat = 1 if topbrand=="PEPSI"
		replace cat = 1 if topbrand=="SEVEN UP"
		replace cat = 1 if topbrand=="SIERRA MIST"
		replace cat = 1 if topbrand=="SPRITE"
		gen top8 = 0
		replace top8 = 1 if topbrand=="COCA-COLA" | topbrand=="PEPSI" | topbrand=="MTN DEW" | topbrand=="DR PEPPER" | topbrand=="BUDWEISER" | topbrand=="MILLER" | topbrand=="COORS" | topbrand=="CORONA"   
		replace topbrand ="OTHER" if cat==1 & top8~=1
		replace topbrand ="OTHERBEER" if cat==2 & top8~=1
	
		collapse (sum) grptv imp000 units, by(topbrand dma market year)
		rename grptv NFLgrps
		rename imp000 NFLimps
		rename unit NFLunits
		sort topbrand dma year
		save "C:\Google Drive\SuperbowlShare\StataData\TopBrandPreSBnflAds", replace
	restore
	
	
	merge m:1 topbrand dma year using "C:\Google Drive\SuperbowlShare\StataData\TopBrandPreSBnflAds"
	
	drop if _merge==2
	replace NFLgrps=0 if _merge==1
	replace NFLimps=0 if _merge==1
	replace NFLunits=0 if _merge==1
	rename _merge NFLmerge

**********************************
* Merge in Weekly GRPs
*   Created in GRPsAllBeer.do and GRPsAllSoda.do
***********************************
	merge 1:1 topbrand dma year superweek using "C:\Google Drive\SuperbowlShare\StataData\WeeklyGRPsBoth"
	tab _merge
	replace PostGRPs=0 if _merge==1
	replace PostIMPs=0 if _merge==1
	replace PostUnits=0 if _merge==1
	drop _merge

**********************************
* Merge in NCAA ratings data
*    Created in RatingsNCAA.do
***********************************
	merge m:1 dma year superweek using "C:\Google Drive\SuperbowlShare\StataData\RTGsNCAA"
	tab _merge
	replace rtgNCAA = 0      if _merge==1
	replace rtgNCAA_lag = 0  if _merge==1
	replace rtgNCAA_lead = 0 if _merge==1
	drop _merge

**********************************
* Load in and Merge in Facebook Likes Data
*    This was collected from querying Facebook's website for potential impressions based in each DMA for people who liked each NFL team
***********************************
	preserve
		clear
		insheet using "C:\Google Drive\SuperbowlShare\RawData\FacebookNew210Chris.txt", names 
		 reshape long year, i(market dmaname) j(temp)
		 rename year liked
		 rename temp year
		 sort market
		 merge m:1 market using "C:\Google Drive\SuperbowlShare\StataData\DMAidMarket"
		 tab _merge
		 drop _merge 
		 sort dma year
		save "C:\Google Drive\SuperbowlShare\StataData\Liked210", replace
	restore
	
	sort market year
	merge m:1 dma year using "C:\Google Drive\SuperbowlShare\StataData\Liked210"
	tab _merge
	drop if _merge==2
	drop _merge


**********************************
* Generating Supplementary Variables
***********************************
	egen totvol=sum(volume),by(cat dma year superweek)
	gen share=volume/totvol
	gen price =  revenue/volume
	
	encode topbrand, gen(brandnum)
	gen brandyear=year*100+brandnum
	gen branddma=dma*100+brandnum
	gen top4=0
	replace top4=1 if topbrand=="BUDWEISER"
	replace top4=1 if topbrand=="MILLER"
	replace top4=1 if topbrand=="COCA-COLA"
	replace top4=1 if topbrand=="PEPSI"

	gen top4vol=volume*top4
	egen totvol4=sum(top4vol),by(cat dma year superweek)
	gen share4=volume/totvol4

**********************************
* Aggregate ad specific ratings into a game-specific ratings variable (by DMA and year)
**********************************
	gen avggrps=SBgrps/SBunits if SBunits>0 & SBunits~=.
	egen rtg=median(avggrps),by(dma year)
	gen avgimps=SBimps/SBunits if SBunits>0 & SBunits~=.
	egen imps=median(avgimps),by(dma year)
	sort market year

**********************************
* Merge in Ratings Data for the top 56 markets
*    These were purchased from Nielsen and are what they report as the viewership for the game
*    For the 57+ markets, we calcluate the game number based on viewership numbers for the ads ... this data was merged within MergeCatYearWeek.do
*    The last step of this section defines a single rtg variable for both top 56 and 57+ markets
***********************************
	merge m:1 market year using "C:\Dropbox\SuperbowlAds\Data\rtgs_NFL"
	   * The above rtgs_NFL file was created from an insheet of the ratings data purchsed from Nielsen
	drop if _merge==2 & year<2006 
	drop if _merge==2 & year==2012
	tab _merge
	gen top56i=(_merge==3)
	egen rtg56=median(RTG),by(dma year)
	gen top56 = rtg56~=.
	drop _merge
	gen rtg_adviews=rtg
	replace rtg=rtg56 if top56


**********************************
* Calculating number of households
***********************************
	egen hh_s56=median(hh_s),by(dma year)
	egen shr56 = median(SHR),by(dma year)
	gen households = (hh_s56*1000)/(shr56/100)
	replace households = (imps*1000)/(rtg/100) if top56==0
	egen medHH = median(households),by(dma)
	gen hh_orig = households
	replace households = medHH


**********************************
* Create Variables for Number of Ads
***********************************
	egen NumAds = median(SBunits),by(topbrand year)
	gen  AnyAd  = NumAds>0
	gen rtg_ad=rtg*AnyAd
	gen rtg_numads=rtg*NumAds


**********************************
* Additional Data Cleaning
***********************************
	egen sumSBgrps=sum(SBgrps),by(topbrand)

	replace rtg_ad=rtg if topbrand=="BUDWEISER" & superweek>0
	replace rtg_ad=0 if topbrand=="OTHERBEER"
	replace rtg_ad=0 if topbrand=="OTHER"

	gen liked_ad=liked*(SBgrps>0)*(superweek>0)

**********************************
* Some Labeling
***********************************
	label variable rtg_ad "Ratings * Ad"
	label variable rtg    "Ratings"
	label variable NFLgrps "Pre-SB NFL GRPs"
	label variable price "Price"
	label variable feature "Feature"
	label variable display "Display"


gen double brandweek=brandyear*100+superweek
gen week0=superweek==0




**********************************
* Edits for Beer Data
***********************************

preserve
	drop if dma==617 & year==2006
	drop if dma==641 & year==2006
	drop if dma==671 & year==2006
	keep if cat==2
	drop if restricted
		drop if households==.
		* Drops Bend Oregon where we have no GRP data
		bysort topbrand dma: gen obBM=_n
		egen maxBM=max(obBM),by(topbrand dma)
		drop if maxBM==1
		bysort topbrand year: gen obBY=_n
		egen maxBY=max(obBY),by(topbrand year)
		drop if maxBY==1
		
		egen countobs = count(rtg),by(topbrand dma superweek)
		keep if countobs>1
		encode topbrand, gen(beerbnum)
		gen yearbeer=year*100+beerbnum
			gen double brandweekS0=yearbeer*100+week0
			tab brandweekS0, gen(Iybw0) 

		sort beerbnum dma year
		gen playoff3=playoff1==3
		gen playoff4=playoff1==4
	save "C:\Google Drive\SuperbowlShare\StataData\NielsenSalesBeerW210", replace



restore




**********************************
* Edits for Soda Data
***********************************


preserve
	keep if cat==1
		drop if households==.
		* Drops Bend Oregon where we have no GRP data
		bysort topbrand dma: gen obBM=_n
		egen maxBM=max(obBM),by(topbrand dma)
		drop if maxBM==1
		bysort topbrand year: gen obBY=_n
		egen maxBY=max(obBY),by(topbrand year)
		drop if maxBY==1
		encode topbrand, gen(sodabnum)

		egen countobs = count(rtg),by(topbrand dma superweek)
		keep if countobs>1

		
		gen yearsoda=year*100+sodabnum
		*tab yearsoda, gen(yearsodaI)
			gen double brandweekS0=yearsoda*100+week0
			tab brandweekS0, gen(Iybw0) 
		sort sodabnum dma year
		gen playoff3=playoff1==3
		gen playoff4=playoff1==4
		 
	save "C:\Google Drive\SuperbowlShare\StataData\NielsenSalesSodaW210", replace

restore


